/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.maven.plugin;

import de.schlichtherle.truezip.file.TFile;
import java.io.*;
import javax.annotation.concurrent.NotThreadSafe;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;

/**
 * Obfuscates constant string values in the test byte code.
 * Note that general Java byte code obfuscation is out of scope for this goal.
 * So to achieve a reasonable level of security for your intellectual property
 * you still need to apply a general byte code obfuscation tool to the
 * transformed class files.
 *
 * @see    net.java.truelicense.obfuscate.ObfuscatedString
 * @author Christian Schlichtherle
 */
@NotThreadSafe
@Mojo(name = "test-obfuscate", defaultPhase = LifecyclePhase.PROCESS_TEST_CLASSES)
public final class TestObfuscateMojo extends ObfuscateMojo {

    @Parameter(defaultValue = "${project.build.testOutputDirectory}", required = true, readonly = true)
    private File testOutputDirectory;

    @Override TFile outputDirectory() { return new TFile(testOutputDirectory); }
}
